

set -ex



test -f $PREFIX/share/icons/Adwaita/icon-theme.cache
test -f $PREFIX/share/icons/Adwaita/index.theme
test -f $PREFIX/share/icons/Adwaita/16x16/devices/computer.png
test -f $PREFIX/share/icons/Adwaita/16x16/devices/computer-symbolic.symbolic.png
test -f $PREFIX/share/icons/Adwaita/cursors/cross
test -f $PREFIX/share/icons/Adwaita/scalable/devices/computer-symbolic.svg
exit 0
